#
# spec file for package python-libsass
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%define _name   libsass-python
Name:           python-libsass
Version:        0.23.0
Release:        1.10
Summary:        Python binding for libsass
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/sass/libsass-python
Source:         https://github.com/sass/libsass-python/archive/%{version}.tar.gz
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libsass-devel >= 3.6.4
BuildRequires:  python-rpm-macros
Requires:       python-setuptools
Requires(post): update-alternatives
Requires(postun):update-alternatives
# SECTION test requirements
BuildRequires:  %{python_module Werkzeug}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
A straightforward binding of libsass for Python. Compile Sass/SCSS in Python
with no Ruby stack at all!

%prep
%setup -q -n libsass-python-%{version}

%build
sed -i -e '/^#!\//, 1d' *.py
export SYSTEM_SASS=true
%python_build

%install
export SYSTEM_SASS=true
%python_install
%python_clone -a %{buildroot}%{_bindir}/pysassc
%{python_expand \
# We don't want to install tests
rm %{buildroot}%{$python_sitearch}/sasstests.py \
   %{buildroot}%{$python_sitearch}/__pycache__/sasstests.*.pyc
%fdupes %{buildroot}%{$python_sitearch}
}

%check
%pytest_arch sasstests.py

%post
%python_install_alternative pysassc

%postun
%python_uninstall_alternative pysassc

%files %{python_files}
%python_alternative %{_bindir}/pysassc
%{python_sitearch}/pysassc.py
%{python_sitearch}/sass.py
%{python_sitearch}/_sass*.so
%{python_sitearch}/sassutils
%pycache_only %{python_sitearch}/__pycache__/*sass*.pyc
%{python_sitearch}/libsass-%{version}*-info

%changelog
* Sat Jan 13 2024 Dirk Müller <dmueller@suse.com>
- update to 0.23.0:
  * Follow up the libsass upstream: 3.6.6 --- See the release
    notes of LibSass 3.6.6.
* Sun Jun 18 2023 Andreas Schneider <asn@cryptomilk.org>
- Use sle15_python_module_pythons
* Mon Mar 13 2023 Matej Cepl <mcepl@suse.com>
- Clean up the SPEC file and tighten it a bit to be less
  all-accepting.
* Mon Mar 13 2023 pgajdos@suse.com
- version update to 0.22.0
  - Remove python 2.x support [:issue:`373` by anthony sottile].
  - Remove deprecated ``sassc`` cli [:issue:`379` by anthony sottile].
- python-six is not required
- do not conflict with sassc package
* Tue Aug  3 2021 Markéta Machová <mmachova@suse.com>
- Update to 0.21.0
  * Follow up the libsass upstream: 3.6.5
* Wed Jul 22 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v0.20.0, linking against libsass 3.6.4
* Mon May 25 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Wed Apr 15 2020 pgajdos@suse.com
- version update to 0.19.4
  * Follow up the libsass upstream: 3.6.3 --- See the release notes of LibSass 3.6.3.
* Wed Jul 24 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.19.2:
  * Follow up the libsass upstream: 3.6.1
* Fri Apr  5 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.18.0:
  * Add support for previous import path to importer callbacks [#287 #291 by Frankie Dintino]
  * Add several new cli options [#279 #268 by Frankie Dintino]
  * Fix compilation on macos mojave [#276 #277 by @asottile]
  * Use -lc++ link flag when compiling with clang [#270 by Christian Thieme #271 by Anthony Sottile]
  * Honor strip_extension in SassMiddleware [#274 by Anthony Sottile]
  * Fix invalid escape sequences [#249 by Anthony Sottile]
  * Add code of conduct [#251 by Nick Schonning]
  * Add support for python3.7 and remove testing for python3.4 [#254 by Anthony Sottile]
  * Add strip_extension option for wsgi / distutils builder [#55 #258 by Anthony Sottile #260 by Morten Brekkevold]
  * Deprecate sassc (replaced by pysassc). [#262 by Anthony Sottile]
  * Import abc classes from collections.abc to remove DeprecationWarning [#264 by Gary van der Merwe #265 by Anthony Sottile]
  * Add ability to specify imports for custom extensions
  * SassList type gained an additional option bracketed=False to match the upstream changes to the sass_list type. [#184 by Anthony Sottile]
  * libsass-python has moved to the sass organization!
  * Sort input files for determinism [#212 by Bernhard M. Wiedemann]
  * Include LICENSE file in distributions [#216 by Dougal J. Sutherland]
  * Add a pysassc entry to replace sassc [#218 by Anthony Sottile]
  * Enable building with dynamic linking [#219 by Marcel Plch]
  * Always add cwd to import paths [#208 by Anthony Sottile]
  * Use getfullargspec when available in python 3. [#188 by Thom Wiggers]
  * Use sass_copy_c_string instead of strdup for portability [#196 by Anthony Sottile]
  * Use -std=gnu++0x to fix installation under cygwin [#195 #197 by Anthony Sottile]
  * Correct source map url [#201 #202 by Anthony Sottile]
  * Remove --watch [#203 by Anthony Sottile]
- Remove merged patch reproducible.patch
- Do not use bundled libsass
* Sat Jul 14 2018 bwiedemann@suse.com
- Add reproducible.patch to sort .o files in linking
  in order to make build reproducible (boo#1041090)
* Mon May 15 2017 cbosdonnat@suse.com
- Update to version 0.12.3
  Drop now useless patch: 89d03d50-allow-t-for-style.patch
* Thu Apr 13 2017 cbosdonnat@suse.com
- Add conflicts: sassc
* Fri Apr  7 2017 jengelh@inai.de
- Drop redundant %%clean section. Replace old $RPM shell vars
  by macros.
* Thu Mar 31 2016 olaf@aepfle.de
- Include egg-info to fix build
* Tue Dec 29 2015 cbosdonnat@suse.com
- 0.10.0 Release
- Use -t for style like ruby sassc
  89d03d50-allow-t-for-style.patch
